@@ -64,11 +64,16 @@ impl fmt::Display for ParseDebugIdError {
 
 /// Unique identifier for debug information files and their debug information.
 ///
-/// The string representation must be between 33 and 40 characters long and
-/// consist of:
+/// This type is analogous to `CodeId`, except that it identifies a debug file instead of the actual
+/// library or executable. One some platforms, a `DebugId` is an alias for a `CodeId` but the exact
+/// rules around this are complex. On Windows, the identifiers are completely different and refer to
+/// separate files.
+///
+/// The string representation must be between 33 and 40 characters
+/// long and consist of:
 ///
 /// 1. 36 character hyphenated hex representation of the UUID field
-/// 2. 1-16 character lowercase hex representation of the u64 appendix
+/// 2. 1-16 character lowercase hex representation of the u32 appendix
 ///
 /// The debug identifier is compatible to Google Breakpad. Use [`DebugId::breakpad`] to get a
 /// breakpad string representation of this debug identifier.
@@ -286,7 +291,8 @@ impl CodeId {
     }
 
     /// Constructs a `CodeId` from its string representation.
-    pub fn new(string: String) -> Self {
+    pub fn new(mut string: String) -> Self {
+        string.make_ascii_lowercase();
         CodeId { inner: string }
     }
 
@@ -320,7 +326,19 @@ impl fmt::Display for CodeId {
 
 impl fmt::Debug for CodeId {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        f.debug_tuple("CodeId").field(&self.as_str()).finish()
+        write!(f, "CodeId({})", self)
+    }
+}
+
+impl From<String> for CodeId {
+    fn from(string: String) -> Self {
+        Self::new(string)
+    }
+}
+
+impl From<&'_ str> for CodeId {
+    fn from(string: &str) -> Self {
+        Self::new(string.into())
     }
 }
 
